local _G = _G
local Cartographer3 = _G.Cartographer3
local L = Cartographer3.L

local panel = CreateFrame("Frame", "Cartographer3_Panel")

panel.name = "Cartographer3"
panel.controls = {}

function panel:okay()
	for control in pairs(self.controls) do
		control.value = control.oldValue
	end
end

function panel:cancel()
	for control in pairs(self.controls) do
		control:SetValue(control.oldValue)
	end
end

function panel:default()
	for control in pairs(self.controls) do
		control:SetValue(control.default)
	end
end

InterfaceOptions_AddCategory(panel)

local makeControls
panel:SetScript("OnShow", function(self)
	self:SetScript("OnShow", nil)
	makeControls(self)
	makeControls = nil
end)

function makeControls(self)
	local title = self:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	title:SetText("Cartographer3")
	title:SetJustifyH("LEFT")
	title:SetJustifyV("TOP")
	title:SetPoint("TOPLEFT", 16, -16)
	
	local subText = self:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
	subText:SetText(L["These options allow you to configure Cartographer3"]) -- TODO: better text
	subText:SetNonSpaceWrap(true)
	subText:SetJustifyH("LEFT")
	subText:SetJustifyV("TOP")
	subText:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -8)
	subText:SetPoint("RIGHT", -32, 0)
	
	local zoomToMinimapTextureSlider = CreateFrame("Slider", panel:GetName() .. "_ZoomToMinimapTextureSlider", panel, "InterfaceOptionsSliderTemplate")
	self.controls[zoomToMinimapTextureSlider] = true
	_G[zoomToMinimapTextureSlider:GetName() .. "Text"]:SetText(L["Texture Change Zoom"])
	_G[zoomToMinimapTextureSlider:GetName() .. "Text"]:SetTextColor(NORMAL_FONT_COLOR.r, NORMAL_FONT_COLOR.g, NORMAL_FONT_COLOR.b)
	_G[zoomToMinimapTextureSlider:GetName() .. "Low"]:SetText(L["Far"])
	_G[zoomToMinimapTextureSlider:GetName() .. "Low"]:SetTextColor(HIGHLIGHT_FONT_COLOR.r, HIGHLIGHT_FONT_COLOR.g, HIGHLIGHT_FONT_COLOR.b)
	_G[zoomToMinimapTextureSlider:GetName() .. "High"]:SetText(L["Near"])
	_G[zoomToMinimapTextureSlider:GetName() .. "High"]:SetTextColor(HIGHLIGHT_FONT_COLOR.r, HIGHLIGHT_FONT_COLOR.g, HIGHLIGHT_FONT_COLOR.b)
	zoomToMinimapTextureSlider.tooltipText = L["The amount to zoom in before the map changes from minimap-style textures to artwork.\n\nNote: Setting this too far may cause severe framerate issues."]
	zoomToMinimapTextureSlider.default = Cartographer3.Data.DEFAULT_ZOOM_TO_MINIMAP_TEXTURE
	zoomToMinimapTextureSlider:SetPoint("TOPLEFT", subText, "BOTTOMLEFT", 0, -32)
	zoomToMinimapTextureSlider:SetMinMaxValues(0, 120)
	zoomToMinimapTextureSlider.oldValue = Cartographer3.db.profile.zoomToMinimapTexture
	zoomToMinimapTextureSlider:SetValue(zoomToMinimapTextureSlider.oldValue)
	local oldSetValue = zoomToMinimapTextureSlider.SetValue
	function zoomToMinimapTextureSlider:SetValue(value)
		oldSetValue(self, value)
		self.value = value
		Cartographer3.db.profile.zoomToMinimapTexture = value
	end
	zoomToMinimapTextureSlider:SetScript("OnValueChanged", function(self)
		self.value = self:GetValue()
		self:SetValue(self:GetValue())
	end)
end
